@@ -5,7 +5,7 @@ use warnings;
 
 use Git::Repository::Plugin;
 our @ISA      = qw( Git::Repository::Plugin );
-our @KEYWORDS = qw( myhello );
+sub _keywords { qw( myhello ) }
 
 sub myhello { return "Hello, my git world!\n" }
 
